@@ -44,19 +44,15 @@ class tester_impl_t(parser_test_case.parser_test_case_t):
         color2 = declarations.matcher.get_single(enum_matcher, decls2)
         self.assertTrue(color1.values == color2.values)
 
-# there is no progress with this parser
-# class synopsis_tester_t( tester_impl_t ):
-#    CXX_PARSER_CFG = autoconfig.cxx_parsers_cfg.synopsis
 
-
-class gccxml_tester_t(tester_impl_t):
+class Test(tester_impl_t):
     CXX_PARSER_CFG = autoconfig.cxx_parsers_cfg.config
 
 
 def create_suite():
     suite = unittest.TestSuite()
-    # suite.addTest( unittest.makeSuite(synopsis_tester_t))
-    suite.addTest(unittest.makeSuite(gccxml_tester_t))
+    suite.addTest(
+        unittest.TestLoader().loadTestsFromTestCase(testCaseClass=Test))
     return suite
 
 
