@@ -592,10 +592,18 @@ class core_file_by_file_no_opt_t(CoreXMLGenerator):
 
 def create_suite():
     suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(core_all_at_once_t))
-    suite.addTest(unittest.makeSuite(core_all_at_once_no_opt_t))
-    suite.addTest(unittest.makeSuite(core_file_by_file_t))
-    suite.addTest(unittest.makeSuite(core_file_by_file_no_opt_t))
+    suite.addTest(
+        unittest.TestLoader().loadTestsFromTestCase(
+            testCaseClass=core_all_at_once_t))
+    suite.addTest(
+        unittest.TestLoader().loadTestsFromTestCase(
+            testCaseClass=core_all_at_once_no_opt_t))
+    suite.addTest(
+        unittest.TestLoader().loadTestsFromTestCase(
+            testCaseClass=core_file_by_file_t))
+    suite.addTest(
+        unittest.TestLoader().loadTestsFromTestCase(
+            testCaseClass=core_file_by_file_no_opt_t))
     return suite
 
 
